SET SQL DIALECT 3;
CREATE DATABASE 'C:\SQLLAB.FDB' USER 'SYSDBA' PASSWORD 'masterkey'
PAGE_SIZE 16384 DEFAULT CHARACTER SET WIN1251;
/*****************************************************************/
/*                                  Domains                                                                   */
/*****************************************************************/
CREATE DOMAIN MONEY AS NUMERIC(15,2);
CREATE DOMAIN TMONTH AS SMALLINT 
CHECK (VALUE BETWEEN 1 AND 12);
CREATE DOMAIN PKFIELD AS INTEGER;
CREATE DOMAIN TYEAR AS SMALLINT
CHECK (VALUE BETWEEN 1990 AND 2100);
/*****************************************************************/
/*                                 Exceptions                                                                 */
/*****************************************************************/
CREATE EXCEPTION INS_RESTRICT '     ';
CREATE EXCEPTION DEL_RESTRICT '     ';
CREATE EXCEPTION UPD_RESTRICT '     ';
/*****************************************************************/
/*                                   Tables                                                                   */
/*****************************************************************/
CREATE TABLE STREET (
    STREETCD  PKFIELD NOT NULL PRIMARY KEY,
    STREETNM  VARCHAR(30) );
CREATE TABLE SERVICES (
    SERVICECD  PKFIELD NOT NULL PRIMARY KEY,
    SERVICENM  VARCHAR(30) );
CREATE TABLE DISREPAIR (
    FAILURECD  PKFIELD NOT NULL PRIMARY KEY,
    FAILURENM  VARCHAR(50) );
CREATE TABLE EXECUTOR (
    EXECUTORCD  PKFIELD NOT NULL PRIMARY KEY,
    Fio  VARCHAR(20) );
CREATE TABLE ABONENT (
    ACCOUNTCD  VARCHAR(6) NOT NULL PRIMARY KEY,
    STREETCD  PKFIELD REFERENCES STREET 
      ON DELETE SET NULL ON UPDATE CASCADE,
    HOUSENO  SMALLINT,
    FLATNO  SMALLINT,
    Fio  VARCHAR(20),
    PHONE  VARCHAR(15));
CREATE TABLE NACHISLSUMMA (
    NACHISLFACTCD  PKFIELD NOT NULL PRIMARY KEY,
    ACCOUNTCD VARCHAR(6) NOT NULL REFERENCES ABONENT
      ON UPDATE CASCADE,
    SERVICECD PKFIELD NOT NULL REFERENCES SERVICES 
      ON UPDATE CASCADE,
    NACHISLSUM     MONEY,
    NACHISLMONTH   TMONTH,
    NACHISLYEAR    TYEAR);
CREATE TABLE PAYSUMMA (
    PAYFACTCD  PKFIELD NOT NULL PRIMARY KEY,
    ACCOUNTCD  VARCHAR(6) NOT NULL REFERENCES ABONENT
      ON UPDATE CASCADE,
    SERVICECD PKFIELD NOT NULL REFERENCES SERVICES
      ON UPDATE CASCADE,
    PAYSUM  MONEY,
    PAYDATE  DATE,
    PAYMONTH  TMONTH,
    PAYYEAR  TYEAR);
CREATE TABLE REQUEST (
    REQUESTCD PKFIELD NOT NULL PRIMARY KEY,
    ACCOUNTCD  VARCHAR(6) REFERENCES ABONENT
      ON DELETE SET NULL ON UPDATE CASCADE,
    EXECUTORCD  PKFIELD REFERENCES EXECUTOR
      ON DELETE SET NULL ON UPDATE CASCADE,
    FAILURECD  PKFIELD REFERENCES DISREPAIR
      ON DELETE SET NULL ON UPDATE CASCADE,
    INCOMINGDATE  DATE,
    EXECUTIONDATE  DATE,
    EXECUTED  BOOLEAN);
/*****************************************************************/
/*                                 Insert  STREET                                                              */
/*****************************************************************/
INSERT INTO STREET (STREETCD, STREETNM) VALUES (3, ' ');
INSERT INTO STREET (STREETCD, STREETNM) VALUES (7, ' ');
INSERT INTO STREET (STREETCD, STREETNM) VALUES (6, ' ');
INSERT INTO STREET (STREETCD, STREETNM) VALUES (8, ' ');
INSERT INTO STREET (STREETCD, STREETNM) VALUES (4, ' ');
INSERT INTO STREET (STREETCD, STREETNM) VALUES (5, ' ');
INSERT INTO STREET (STREETCD, STREETNM) VALUES (1, ' ');
INSERT INTO STREET (STREETCD, STREETNM) VALUES (2, ' ');
COMMIT WORK;
/*****************************************************************/
/*                                 Insert  SERVICES                                                            */
/*****************************************************************/
INSERT INTO SERVICES (SERVICECD, SERVICENM) VALUES (1, '');
INSERT INTO SERVICES (SERVICECD, SERVICENM) VALUES (2, '');
INSERT INTO SERVICES (SERVICECD, SERVICENM) VALUES (3, '');
INSERT INTO SERVICES (SERVICECD, SERVICENM) VALUES (4, '');
COMMIT WORK;
/*****************************************************************/
/*                                 Insert  DISREPAIR                                                           */
/*****************************************************************/
INSERT INTO DISREPAIR (FAILURECD, FAILURENM) VALUES (1, '  ');
INSERT INTO DISREPAIR (FAILURECD, FAILURENM) VALUES (2, '  ');
INSERT INTO DISREPAIR (FAILURECD, FAILURENM) VALUES (3, '   ');
INSERT INTO DISREPAIR (FAILURECD, FAILURENM) VALUES (4, '  ');
INSERT INTO DISREPAIR (FAILURECD, FAILURENM) VALUES (5, '  ');
INSERT INTO DISREPAIR (FAILURECD, FAILURENM) VALUES (6, '     ');
INSERT INTO DISREPAIR (FAILURECD, FAILURENM) VALUES (7, '    ');
INSERT INTO DISREPAIR (FAILURECD, FAILURENM) VALUES (8, '      ');
INSERT INTO DISREPAIR (FAILURECD, FAILURENM) VALUES (12, '');
COMMIT WORK;
/*****************************************************************/
/*                                 Insert  EXECUTOR                                                            */
/*****************************************************************/
INSERT INTO EXECUTOR (EXECUTORCD, FIO) VALUES (1, ' ..');
INSERT INTO EXECUTOR (EXECUTORCD, FIO) VALUES (2, ' ..');
INSERT INTO EXECUTOR (EXECUTORCD, FIO) VALUES (3, ' ..');
INSERT INTO EXECUTOR (EXECUTORCD, FIO) VALUES (4, ' ..');
INSERT INTO EXECUTOR (EXECUTORCD, FIO) VALUES (5, ' ..');
COMMIT WORK;
/*****************************************************************/
/*                                 Insert  ABONENT                                                             */
/*****************************************************************/
INSERT INTO ABONENT (ACCOUNTCD, STREETCD, HOUSENO, FLATNO, FIO, PHONE) VALUES ('005488', 7, 4, 1, ' ..', '556893');
INSERT INTO ABONENT (ACCOUNTCD, STREETCD, HOUSENO, FLATNO, FIO, PHONE) VALUES ('115705', 3, 1, 82, ' ..', '769975');
INSERT INTO ABONENT (ACCOUNTCD, STREETCD, HOUSENO, FLATNO, FIO, PHONE) VALUES ('015527', 3, 1, 65, ' ..', '761699');
INSERT INTO ABONENT (ACCOUNTCD, STREETCD, HOUSENO, FLATNO, FIO, PHONE) VALUES ('443690', 7, 5, 1, ' ..', '214833');
INSERT INTO ABONENT (ACCOUNTCD, STREETCD, HOUSENO, FLATNO, FIO, PHONE) VALUES ('136159', 7, 39, 1, ' ..', NULL);
INSERT INTO ABONENT (ACCOUNTCD, STREETCD, HOUSENO, FLATNO, FIO, PHONE) VALUES ('443069', 4, 51, 55, ' ..', '683014');
INSERT INTO ABONENT (ACCOUNTCD, STREETCD, HOUSENO, FLATNO, FIO, PHONE) VALUES ('136160', 4, 9, 15, ' ..', NULL);
INSERT INTO ABONENT (ACCOUNTCD, STREETCD, HOUSENO, FLATNO, FIO, PHONE) VALUES ('126112', 4, 7, 11, ' ..', '683301');
INSERT INTO ABONENT (ACCOUNTCD, STREETCD, HOUSENO, FLATNO, FIO, PHONE) VALUES ('136169', 4, 7, 13, ' ..', '680305');
INSERT INTO ABONENT (ACCOUNTCD, STREETCD, HOUSENO, FLATNO, FIO, PHONE) VALUES ('080613', 8, 35, 11, ' ..', '254417');
INSERT INTO ABONENT (ACCOUNTCD, STREETCD, HOUSENO, FLATNO, FIO, PHONE) VALUES ('080047', 8, 39, 36, ' ..', '257842');
INSERT INTO ABONENT (ACCOUNTCD, STREETCD, HOUSENO, FLATNO, FIO, PHONE) VALUES ('080270', 6, 35, 6, ' ..', '321002');
COMMIT WORK;
/*****************************************************************/
/*                                 Insert  NACHISLSUMMA                                                 */
/*****************************************************************/
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (19, '005488', 2, 58.7, 12, 2011);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (2, '005488', 2, 46, 12, 2010);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (3, '005488', 2, 56, 4, 2013);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (4, '115705', 2, 40, 1, 2010);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (5, '115705', 2, 250, 9, 2011);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (13, '136160', 2, 20, 5, 2011);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (1, '136160', 2, 56, 1, 2013);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (15, '136169', 2, 20, 5, 2011);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (7, '080047', 2, 80, 10, 2012);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (8, '080047', 2, 80, 10, 2011);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (9, '080270', 2, 46, 12, 2011);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (10, '080613', 2, 56, 6, 2011);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (11, '115705', 2, 250, 9, 2010);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (12, '115705', 2, 58.7, 8, 2011);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (16, '136169', 2, 58.7, 11, 2011);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (17, '443069', 2, 80, 9, 2011);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (18, '443069', 2, 38.5, 8, 2011);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (6, '136160', 1, 18.3, 1, 2012);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (20, '015527', 1, 28.32, 7, 2012);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (21, '080047', 1, 19.56, 3, 2012);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (22, '080613', 1, 10.6, 9, 2012);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (23, '443069', 1, 38.28, 12, 2012);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (24, '015527', 1, 38.32, 4, 2013);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (25, '115705', 1, 37.15, 10, 2013);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (26, '080613', 1, 12.6, 8, 2010);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (27, '136169', 1, 25.32, 1, 2013);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (28, '080270', 1, 57.1, 2, 2012);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (29, '136159', 1, 8.3, 8, 2013);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (30, '005488', 1, 62.13, 4, 2010);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (31, '115705', 1, 37.8, 5, 2011);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (32, '443690', 1, 17.8, 6, 2012);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (33, '080047', 1, 22.56, 5, 2013);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (34, '126112', 1, 15.3, 8, 2010);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (35, '080047', 1, 32.56, 9, 2011);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (36, '080613', 1, 12.6, 4, 2012);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (37, '115705', 1, 37.15, 11, 2013);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (38, '080270', 1, 58.1, 12, 2010);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (39, '136169', 1, 28.32, 1, 2011);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (40, '015527', 1, 18.32, 2, 2012);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (41, '443690', 1, 21.67, 3, 2013);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (42, '080613', 1, 22.86, 4, 2010);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (43, '080270', 1, 60.1, 5, 2011);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (44, '136169', 1, 28.32, 2, 2012);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (45, '080047', 1, 22.2, 7, 2013);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (46, '126112', 1, 25.3, 8, 2011);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (47, '443069', 1, 38.32, 9, 2011);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (48, '136159', 1, 8.3, 10, 2012);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (49, '115705', 1, 37.15, 6, 2013);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (50, '136160', 1, 18.3, 12, 2010);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (51, '005488', 3, 279.8, 5, 2012);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (52, '005488', 3, 266.7, 2, 2013);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (53, '015527', 3, 343.36, 11, 2013);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (54, '080047', 3, 271.6, 2, 2013);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (55, '080270', 3, 278.25, 11, 2013);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (56, '080613', 3, 254.4, 7, 2011);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (57, '080613', 3, 258.8, 2, 2013);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (58, '080613', 3, 239.33, 5, 2013);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (59, '126112', 3, 179.9, 4, 2012);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (60, '136159', 3, 180.13, 9, 2013);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (61, '136160', 3, 238.8, 3, 2010);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (62, '136160', 3, 237.38, 3, 2011);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (63, '136169', 3, 349.19, 6, 2012);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (64, '136169', 3, 346.18, 7, 2012);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (65, '443690', 3, 290.33, 3, 2013);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (66, '015527', 4, 580.1, 7, 2012);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (67, '015527', 4, 611.3, 10, 2013);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (68, '080270', 4, 444.34, 3, 2011);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (69, '080270', 4, 453.43, 6, 2012);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (70, '080270', 4, 454.6, 4, 2013);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (71, '115705', 4, 553.85, 1, 2012);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (72, '126112', 4, 435.5, 6, 2012);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (73, '136159', 4, 349.38, 4, 2011);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (74, '136159', 4, 418.88, 6, 2012);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (75, '136169', 4, 528.44, 10, 2013);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (76, '443069', 4, 466.69, 5, 2012);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (77, '443069', 4, 444.45, 10, 2013);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (78, '443690', 4, 480.88, 8, 2011);
INSERT INTO NACHISLSUMMA (NACHISLFACTCD, ACCOUNTCD, SERVICECD, NACHISLSUM, NACHISLMONTH, NACHISLYEAR) VALUES (79, '443690', 4, 500.13, 9, 2012);
COMMIT WORK;
/*****************************************************************/
/*                                 Insert  PAYSUMMA                                                          */
/*****************************************************************/
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (1, '005488', 2, 58.7, '2012-01-08', 12, 2011);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (2, '005488', 2, 40, '2011-01-06', 12, 2010);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (3, '005488', 2, 56, '2013-05-06', 4, 2013);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (4, '115705', 2, 40, '2010-02-10', 1, 2010);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (5, '115705', 2, 250, '2011-10-03', 9, 2011);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (6, '136160', 2, 20, '2011-06-13', 5, 2011);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (7, '136160', 2, 56, '2013-02-12', 1, 2013);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (8, '136169', 2, 20, '2011-06-22', 5, 2011);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (9, '080047', 2, 80, '2012-11-26', 10, 2012);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (10, '080047', 2, 80, '2011-11-21', 10, 2011);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (11, '080270', 2, 30, '2012-01-03', 12, 2011);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (12, '080613', 2, 58.5, '2011-07-19', 6, 2011);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (13, '115705', 2, 250, '2010-10-06', 9, 2010);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (14, '115705', 2, 58.7, '2011-09-04', 8, 2011);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (15, '136169', 2, 58.7, '2011-12-01', 11, 2011);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (16, '443069', 2, 80, '2011-10-03', 9, 2011);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (17, '443069', 2, 38.5, '2011-09-13', 8, 2011);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (18, '136160', 1, 18, '2012-02-05', 1, 2012);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (19, '015527', 1, 30, '2012-08-03', 7, 2012);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (20, '080047', 1, 19.56, '2012-04-02', 3, 2012);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (21, '080613', 1, 11, '2012-10-03', 9, 2012);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (22, '443069', 1, 38.28, '2013-02-04', 12, 2012);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (23, '015527', 1, 40, '2013-05-07', 4, 2013);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (24, '115705', 1, 37.15, '2013-11-04', 10, 2013);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (25, '080613', 1, 12, '2010-09-20', 8, 2010);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (26, '136169', 1, 25.32, '2013-02-03', 1, 2013);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (27, '080270', 1, 60, '2012-03-05', 2, 2012);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (28, '136159', 1, 8.3, '2013-09-10', 8, 2013);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (29, '005488', 1, 65, '2010-05-03', 4, 2010);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (30, '115705', 1, 37.8, '2011-07-12', 5, 2011);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (31, '443690', 1, 20, '2012-07-10', 6, 2012);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (32, '080047', 1, 22.56, '2013-06-25', 5, 2013);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (33, '126112', 1, 15.3, '2010-09-08', 8, 2010);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (34, '080047', 1, 32.56, '2011-10-18', 9, 2011);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (35, '080613', 1, 12.6, '2012-05-22', 4, 2012);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (36, '115705', 1, 37.15, '2013-12-23', 11, 2013);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (37, '080270', 1, 58.1, '2011-01-07', 12, 2010);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (38, '136169', 1, 28.32, '2011-02-08', 1, 2011);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (39, '015527', 1, 20, '2012-03-18', 2, 2012);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (40, '443690', 1, 19.47, '2013-04-10', 3, 2013);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (41, '080613', 1, 22.86, '2010-05-04', 4, 2010);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (42, '080270', 1, 60, '2011-06-07', 5, 2011);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (43, '136169', 1, 28.32, '2012-03-05', 2, 2012);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (44, '080047', 1, 22.2, '2013-08-10', 7, 2013);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (45, '126112', 1, 25.3, '2011-09-10', 8, 2011);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (46, '443069', 1, 38.32, '2011-10-09', 9, 2011);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (47, '136159', 1, 8.3, '2012-11-14', 10, 2012);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (48, '115705', 1, 37.15, '2013-08-10', 6, 2013);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (49, '136160', 1, 16, '2011-01-07', 12, 2010);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (50, '005488', 3, 280, '2012-06-10', 5, 2012);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (51, '005488', 3, 260, '2013-03-11', 2, 2013);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (52, '015527', 3, 345, '2013-12-15', 11, 2013);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (53, '080047', 3, 271.6, '2013-03-12', 2, 2013);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (54, '080270', 3, 278, '2013-12-06', 11, 2013);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (55, '080613', 3, 254.4, '2011-08-10', 7, 2011);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (56, '080613', 3, 258.8, '2013-03-08', 2, 2013);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (57, '080613', 3, 239.35, '2013-06-11', 5, 2013);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (58, '126112', 3, 179.9, '2012-05-01', 4, 2012);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (59, '136159', 3, 180.13, '2013-10-21', 9, 2013);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (60, '136160', 3, 240, '2010-04-04', 3, 2010);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (61, '136160', 3, 200, '2011-04-06', 3, 2011);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (62, '136169', 3, 349.19, '2012-07-14', 6, 2012);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (63, '136169', 3, 346.18, '2012-08-13', 7, 2012);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (64, '443690', 3, 295, '2013-04-09', 3, 2013);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (65, '015527', 4, 580.1, '2012-08-08', 7, 2012);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (66, '015527', 4, 611.3, '2013-11-03', 10, 2013);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (67, '080270', 4, 444.5, '2011-04-18', 3, 2011);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (68, '080270', 4, 450, '2012-07-14', 6, 2012);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (69, '080270', 4, 460, '2013-05-12', 4, 2013);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (70, '115705', 4, 553.85, '2012-02-02', 1, 2012);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (71, '126112', 4, 435.5, '2012-07-12', 6, 2012);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (72, '136159', 4, 349.38, '2011-05-18', 4, 2011);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (73, '136159', 4, 420, '2012-07-09', 6, 2012);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (74, '136169', 4, 528.44, '2013-11-26', 10, 2013);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (75, '443069', 4, 466.69, '2012-06-03', 5, 2012);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (76, '443069', 4, 444.45, '2013-11-16', 10, 2013);
INSERT INTO PAYSUMMA (PAYFACTCD, ACCOUNTCD, SERVICECD, PAYSUM, PAYDATE, PAYMONTH, PAYYEAR) VALUES (77, '443690', 4, 485, '2011-09-05', 8, 2011);
COMMIT WORK;
/*****************************************************************/
/*                                 Insert  REQUEST                                                               */
/*****************************************************************/
INSERT INTO REQUEST (REQUESTCD, ACCOUNTCD, EXECUTORCD, FAILURECD, INCOMINGDATE, EXECUTIONDATE, EXECUTED) VALUES (1, '005488', 1, 1, '2011-12-17', '2011-12-20', True);
INSERT INTO REQUEST (REQUESTCD, ACCOUNTCD, EXECUTORCD, FAILURECD, INCOMINGDATE, EXECUTIONDATE, EXECUTED) VALUES (2, '115705', 3, 1, '2011-08-07', '2011-08-12', True);
INSERT INTO REQUEST (REQUESTCD, ACCOUNTCD, EXECUTORCD, FAILURECD, INCOMINGDATE, EXECUTIONDATE, EXECUTED) VALUES (3, '015527', 1, 12, '2012-02-28', '2012-03-08', False);
INSERT INTO REQUEST (REQUESTCD, ACCOUNTCD, EXECUTORCD, FAILURECD, INCOMINGDATE, EXECUTIONDATE, EXECUTED) VALUES (5, '080270', 4, 1, '2011-12-31', NULL, False);
INSERT INTO REQUEST (REQUESTCD, ACCOUNTCD, EXECUTORCD, FAILURECD, INCOMINGDATE, EXECUTIONDATE, EXECUTED) VALUES (6, '080613', 1, 6, '2011-06-16', '2011-06-24', True);
INSERT INTO REQUEST (REQUESTCD, ACCOUNTCD, EXECUTORCD, FAILURECD, INCOMINGDATE, EXECUTIONDATE, EXECUTED) VALUES (7, '080047', 3, 2, '2012-10-20', '2012-10-24', True);
INSERT INTO REQUEST (REQUESTCD, ACCOUNTCD, EXECUTORCD, FAILURECD, INCOMINGDATE, EXECUTIONDATE, EXECUTED) VALUES (9, '136169', 2, 1, '2011-11-06', '2011-11-08', True);
INSERT INTO REQUEST (REQUESTCD, ACCOUNTCD, EXECUTORCD, FAILURECD, INCOMINGDATE, EXECUTIONDATE, EXECUTED) VALUES (10, '136159', 3, 12, '2011-04-01', '2011-04-03', False);
INSERT INTO REQUEST (REQUESTCD, ACCOUNTCD, EXECUTORCD, FAILURECD, INCOMINGDATE, EXECUTIONDATE, EXECUTED) VALUES (11, '136160', 1, 6, '2013-01-12', '2013-01-12', True);
INSERT INTO REQUEST (REQUESTCD, ACCOUNTCD, EXECUTORCD, FAILURECD, INCOMINGDATE, EXECUTIONDATE, EXECUTED) VALUES (12, '443069', 5, 2, '2011-08-08', '2011-08-10', True);
INSERT INTO REQUEST (REQUESTCD, ACCOUNTCD, EXECUTORCD, FAILURECD, INCOMINGDATE, EXECUTIONDATE, EXECUTED) VALUES (13, '005488', 5, 8, '2010-09-04', '2010-12-05', True);
INSERT INTO REQUEST (REQUESTCD, ACCOUNTCD, EXECUTORCD, FAILURECD, INCOMINGDATE, EXECUTIONDATE, EXECUTED) VALUES (14, '005488', 4, 6, '2013-04-04', '2013-04-13', True);
INSERT INTO REQUEST (REQUESTCD, ACCOUNTCD, EXECUTORCD, FAILURECD, INCOMINGDATE, EXECUTIONDATE, EXECUTED) VALUES (15, '115705', 4, 5, '2010-09-20', '2010-09-23', True);
INSERT INTO REQUEST (REQUESTCD, ACCOUNTCD, EXECUTORCD, FAILURECD, INCOMINGDATE, EXECUTIONDATE, EXECUTED) VALUES (16, '115705', NULL, 3, '2011-12-28', NULL, False);
INSERT INTO REQUEST (REQUESTCD, ACCOUNTCD, EXECUTORCD, FAILURECD, INCOMINGDATE, EXECUTIONDATE, EXECUTED) VALUES (17, '115705', 1, 5, '2011-08-15', '2011-09-06', True);
INSERT INTO REQUEST (REQUESTCD, ACCOUNTCD, EXECUTORCD, FAILURECD, INCOMINGDATE, EXECUTIONDATE, EXECUTED) VALUES (18, '115705', 2, 3, '2012-12-28', '2013-01-04', True);
INSERT INTO REQUEST (REQUESTCD, ACCOUNTCD, EXECUTORCD, FAILURECD, INCOMINGDATE, EXECUTIONDATE, EXECUTED) VALUES (19, '080270', 4, 8, '2011-12-17', '2011-12-27', True);
INSERT INTO REQUEST (REQUESTCD, ACCOUNTCD, EXECUTORCD, FAILURECD, INCOMINGDATE, EXECUTIONDATE, EXECUTED) VALUES (20, '080047', 3, 2, '2011-10-11', '2011-10-11', True);
INSERT INTO REQUEST (REQUESTCD, ACCOUNTCD, EXECUTORCD, FAILURECD, INCOMINGDATE, EXECUTIONDATE, EXECUTED) VALUES (21, '443069', 1, 2, '2011-09-13', '2011-09-14', True);
INSERT INTO REQUEST (REQUESTCD, ACCOUNTCD, EXECUTORCD, FAILURECD, INCOMINGDATE, EXECUTIONDATE, EXECUTED) VALUES (22, '136160', 1, 7, '2011-05-18', '2011-05-25', True);
INSERT INTO REQUEST (REQUESTCD, ACCOUNTCD, EXECUTORCD, FAILURECD, INCOMINGDATE, EXECUTIONDATE, EXECUTED) VALUES (23, '136169', 5, 7, '2011-05-07', '2011-05-08', True);
COMMIT WORK;
/*****************************************************************/
/*                                  Triggers                                                                              */
/*****************************************************************/
SET TERM ^ ;
CREATE TRIGGER TD_ABONENT FOR ABONENT
ACTIVE AFTER DELETE POSITION 0
AS
DECLARE VARIABLE NUMROWS INTEGER;
BEGIN
    SELECT COUNT(*)
      FROM NACHISLSUMMA
      WHERE
        NACHISLSUMMA.ACCOUNTCD = OLD.ACCOUNTCD INTO NUMROWS;
    IF (NUMROWS > 0) THEN
    BEGIN
      EXCEPTION Del_Restrict;
    END    
    SELECT COUNT(*)
      FROM PAYSUMMA
      WHERE
        PAYSUMMA.ACCOUNTCD = OLD.ACCOUNTCD INTO NUMROWS;
    IF (NUMROWS > 0) THEN
    BEGIN
      EXCEPTION Del_Restrict;
    END
END
^
CREATE TRIGGER TD_SERVICES FOR SERVICES
ACTIVE AFTER DELETE POSITION 0
AS
DECLARE VARIABLE NUMROWS INTEGER;
BEGIN
    SELECT COUNT(*)
      FROM NACHISLSUMMA
      WHERE
        NACHISLSUMMA.SERVICECD = OLD.SERVICECD INTO NUMROWS;
    IF (NUMROWS > 0) THEN
    BEGIN
      EXCEPTION Del_Restrict;
    END
    SELECT COUNT(*)
      FROM PAYSUMMA
      WHERE
        PAYSUMMA.SERVICECD = OLD.SERVICECD INTO NUMROWS;
    IF (NUMROWS > 0) THEN
    BEGIN
      EXCEPTION Del_Restrict;
    END
END
^
SET TERM ; ^

